@@ -1,6 +1,6 @@
 //! Accompanying library for [ic-event-hub-macros](https://crates.io/crates/ic-event-hub-macros)
 
-#![warn(missing_docs)]
+pub mod macros;
 
 /// Client struct used to interact with canisters which implement `event-emitter` with type-safety
 pub mod api;
@@ -11,5 +11,8 @@ pub mod event_hub;
 /// Various structs and traits
 pub mod types;
 
+/// Lower level function to be used inside macros
+pub mod fns;
+
 /// Marker that enables event name serialization
 pub const EVENT_NAME_FIELD: &str = "__event_name";
